EotE Dice
=========

.. image:: https://badge.fury.io/py/eote-dice.png
    :target: http://badge.fury.io/py/eote-dice

Analyze SW EotE role-playing game dice pools.

Installation
------------

You can install, upgrade, and uninstall ``eote-dice`` with these commands:

.. code:: shell-session

    $ pip install eote-dice
    $ pip install --upgrade eote-dice
    $ pip uninstall eote-dice

Usage
-----

Input the dice pool using the first letter of the color of the die (except black Setback die which
use "k").

.. code:: shell-session

    $ eote_dice --pool "yygbrppk"


Releases
--------

0.1.0 - 2015-12-23
^^^^^^^^^^^^^^^^^^

First release.